==> zio-aws-lightsail_2.12-5.17.206.1-sources.jar: zio/aws/lightsail/model/LoadBalancerTlsCertificateDomainValidationRecord.scala <==
package zio.aws.lightsail.model
import zio.aws.lightsail.model.primitives.{DomainName, NonEmptyString}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class LoadBalancerTlsCertificateDomainValidationRecord(
    name: Optional[NonEmptyString] = Optional.Absent,
    `type`: Optional[NonEmptyString] = Optional.Absent,
    value: Optional[NonEmptyString] = Optional.Absent,
    validationStatus: Optional[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainStatus
    ] = Optional.Absent,
    domainName: Optional[DomainName] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord = {
    import LoadBalancerTlsCertificateDomainValidationRecord.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord
      .builder()
      .optionallyWith(
        name.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(
        `type`.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.`type`)
      .optionallyWith(
        value.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.value)
      .optionallyWith(validationStatus.map(value => value.unwrap))(
        _.validationStatus
      )
      .optionallyWith(
        domainName.map(value => DomainName.unwrap(value): java.lang.String)
      )(_.domainName)
      .build()
  }
  def asReadOnly
      : zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord.ReadOnly =
    zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord
      .wrap(buildAwsValue())
}
object LoadBalancerTlsCertificateDomainValidationRecord {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord =
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord(
        name.map(value => value),
        `type`.map(value => value),
        value.map(value => value),
        validationStatus.map(value => value),
        domainName.map(value => value)
      )
    def name: Optional[NonEmptyString]
    def `type`: Optional[NonEmptyString]
    def value: Optional[NonEmptyString]
    def validationStatus: Optional[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainStatus
    ]
    def domainName: Optional[DomainName]
    def getName: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("name", name)
    def getType: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("type", `type`)
    def getValue: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("value", value)
    def getValidationStatus: ZIO[
      Any,
      AwsError,
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainStatus
    ] = AwsError.unwrapOptionField("validationStatus", validationStatus)
    def getDomainName: ZIO[Any, AwsError, DomainName] =
      AwsError.unwrapOptionField("domainName", domainName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord
  ) extends zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord.ReadOnly {
    override val name: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val `type`: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.`type`())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val value: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.value())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val validationStatus: Optional[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainStatus
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.validationStatus())
      .map(value =>
        zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainStatus
          .wrap(value)
      )
    override val domainName: Optional[DomainName] = zio.aws.core.internal
      .optionalFromNullable(impl.domainName())
      .map(value => zio.aws.lightsail.model.primitives.DomainName(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord
  ): zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-lightsail_2.12-5.19.7.3-sources.jar: zio/aws/lightsail/model/LoadBalancerTlsCertificateDomainValidationRecord.scala <==
package zio.aws.lightsail.model
import zio.aws.lightsail.model.primitives.{DomainName, NonEmptyString}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class LoadBalancerTlsCertificateDomainValidationRecord(
    name: Optional[NonEmptyString] = Optional.Absent,
    `type`: Optional[NonEmptyString] = Optional.Absent,
    value: Optional[NonEmptyString] = Optional.Absent,
    validationStatus: Optional[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainStatus
    ] = Optional.Absent,
    domainName: Optional[DomainName] = Optional.Absent,
    dnsRecordCreationState: Optional[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDnsRecordCreationState
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord = {
    import LoadBalancerTlsCertificateDomainValidationRecord.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord
      .builder()
      .optionallyWith(
        name.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(
        `type`.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.`type`)
      .optionallyWith(
        value.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.value)
      .optionallyWith(validationStatus.map(value => value.unwrap))(
        _.validationStatus
      )
      .optionallyWith(
        domainName.map(value => DomainName.unwrap(value): java.lang.String)
      )(_.domainName)
      .optionallyWith(
        dnsRecordCreationState.map(value => value.buildAwsValue())
      )(_.dnsRecordCreationState)
      .build()
  }
  def asReadOnly
      : zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord.ReadOnly =
    zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord
      .wrap(buildAwsValue())
}
object LoadBalancerTlsCertificateDomainValidationRecord {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord =
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord(
        name.map(value => value),
        `type`.map(value => value),
        value.map(value => value),
        validationStatus.map(value => value),
        domainName.map(value => value),
        dnsRecordCreationState.map(value => value.asEditable)
      )
    def name: Optional[NonEmptyString]
    def `type`: Optional[NonEmptyString]
    def value: Optional[NonEmptyString]
    def validationStatus: Optional[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainStatus
    ]
    def domainName: Optional[DomainName]
    def dnsRecordCreationState: Optional[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDnsRecordCreationState.ReadOnly
    ]
    def getName: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("name", name)
    def getType: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("type", `type`)
    def getValue: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("value", value)
    def getValidationStatus: ZIO[
      Any,
      AwsError,
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainStatus
    ] = AwsError.unwrapOptionField("validationStatus", validationStatus)
    def getDomainName: ZIO[Any, AwsError, DomainName] =
      AwsError.unwrapOptionField("domainName", domainName)
    def getDnsRecordCreationState: ZIO[
      Any,
      AwsError,
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDnsRecordCreationState.ReadOnly
    ] = AwsError.unwrapOptionField(
      "dnsRecordCreationState",
      dnsRecordCreationState
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord
  ) extends zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord.ReadOnly {
    override val name: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val `type`: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.`type`())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val value: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.value())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
    override val validationStatus: Optional[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainStatus
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.validationStatus())
      .map(value =>
        zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainStatus
          .wrap(value)
      )
    override val domainName: Optional[DomainName] = zio.aws.core.internal
      .optionalFromNullable(impl.domainName())
      .map(value => zio.aws.lightsail.model.primitives.DomainName(value))
    override val dnsRecordCreationState: Optional[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDnsRecordCreationState.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.dnsRecordCreationState())
      .map(value =>
        zio.aws.lightsail.model.LoadBalancerTlsCertificateDnsRecordCreationState
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord
  ): zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationRecord.ReadOnly =
    new Wrapper(impl)
}
